OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Įterptas laiškas %s",
    "Important mail" : "Svarbūs laiškai",
    "No message found yet" : "Kol kas nerasta jokių el. laiškų",
    "Set up an account" : "Nusistatyti paskyrą",
    "Unread mail" : "Neskaitytas paštas",
    "Important" : "Svarbūs",
    "Work" : "Darbas",
    "Personal" : "Asmeniniai",
    "Later" : "Vėliau",
    "Mail" : "Paštas",
    "Mails" : "El. laiškai",
    "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
    "Your session has expired. The page will be reloaded." : "Jūsų seansas nebegalioja. Puslapis bus įkeltas iš naujo.",
    "Drafts are saved in:" : "Juodraščiai yra įrašomi į:",
    "Sent messages are saved in:" : "Išsiųsti laiškai yra įrašomi į:",
    "Deleted messages are moved in:" : "Ištrinti laiškai yra perkeliami į:",
    "Archived messages are moved in:" : "Archyvuoti laiškai yra perkeliami į:",
    "Connecting" : "Jungiamasi",
    "Reconnect Google account" : "Iš naujo prijungti „Google“ paskyrą",
    "Sign in with Google" : "Prisijungti naudojant „Google“",
    "Reconnect Microsoft account" : "Iš naujo prijungti „Microsoft“ paskyrą",
    "Sign in with Microsoft" : "Prisijungti naudojant „Microsoft“",
    "Save" : "Įrašyti",
    "Connect" : "Prisijungti",
    "Looking up configuration" : "Ieškoma konfigūracijos",
    "Checking mail host connectivity" : "Tikrinamas jungiamumas su pašto serveriu",
    "Configuration discovery failed. Please use the manual settings" : "Nepavyko atrasti konfigūracijos. Naudokite rankinius nustatymus",
    "Password required" : "Reikalingas slaptažodis",
    "Testing authentication" : "Išbandomas tapatybės nustatymas",
    "Awaiting user consent" : "Laukiama naudotojo sutikimo",
    "Account updated" : "Paskyra atnaujinta",
    "IMAP server is not reachable" : "IMAP serveris yra nepasiekiamas",
    "SMTP server is not reachable" : "SMTP serveris yra nepasiekiamas",
    "IMAP username or password is wrong" : "Neteisingas IMAP naudotojo vardas ar slaptažodis",
    "SMTP username or password is wrong" : "Neteisingas SMTP naudotojo vardas ar slaptažodis",
    "IMAP connection failed" : "IMAP ryšys patyrė nesėkmę",
    "SMTP connection failed" : "SMTP ryšys patyrė nesėkmę",
    "There was an error while setting up your account" : "Nustatant jūsų paskyrą įvyko klaida",
    "Auto" : "Automatiškai",
    "Name" : "Vardas",
    "Mail address" : "El. pašto adresas",
    "Password" : "Slaptažodis",
    "Manual" : "Rankiniu būdu",
    "IMAP Settings" : "IMAP nustatymai",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP saugumas",
    "None" : "Nėra",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP prievadas",
    "IMAP User" : "IMAP naudotojo vardas",
    "IMAP Password" : "IMAP slaptažodis",
    "SMTP Settings" : "SMTP nustatymai",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP saugumas",
    "SMTP Port" : "SMTP prievadas",
    "SMTP User" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Account settings" : "Paskyros nustatymai",
    "Aliases" : "Pseudonimai",
    "Signature" : "Parašas",
    "A signature is added to the text of new messages and replies." : "Parašas yra pridedamas į naujų ir atsakomųjų laiškų tekstą.",
    "Writing mode" : "Rašymo veiksena",
    "Preferred writing mode for new messages and replies." : "Pageidaujama rašymo veiksena naujuose laiškuose ir atsakant į laiškus.",
    "Default folders" : "Numatytieji aplankai",
    "Autoresponder" : "Atsakiklis",
    "Filters" : "Filtrai",
    "Mail server" : "Pašto serveris",
    "Go back" : "Grįžti",
    "Change name" : "Keisti vardą",
    "Email address" : "El. pašto adresas",
    "Add alias" : "Pridėti alternatyvų vardą",
    "Cancel" : "Atsisakyti",
    "Use internal addresses" : "Naudoti vidinius adresus",
    "Could not update preference" : "Nepavyko atnaujinti nuostatos",
    "Mail settings" : "Pašto nustatymai",
    "Accounts" : "Paskyros",
    "Add mail account" : "Pridėti pašto paskyrą",
    "General" : "Bendra",
    "Layout" : "Išdėstymas",
    "List" : "Sąrašas",
    "Sorting" : "Rikiavimas",
    "Newest" : "Naujausios",
    "Oldest" : "Seniausios",
    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
    "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
    "Register" : "Registruotis",
    "Privacy and security" : "Privatumas ir saugumas",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
    "Trusted senders" : "Patikimi siuntėjai",
    "Internal addresses" : "Vidiniai adresai",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus",
    "About" : "Apie",
    "Keyboard shortcuts" : "Spartieji klavišai",
    "Compose new message" : "Rašyti naują laišką",
    "Newer message" : "Naujesni laiškai",
    "Older message" : "Senesni laiškai",
    "Toggle star" : "Perjungti laiško žymėjimą, kaip pažymėtą žvaigždute",
    "Toggle unread" : "Perjungti laiško žymėjimą, kaip neskaityto",
    "Archive" : "Archyvuoti",
    "Delete" : "Ištrinti",
    "Search" : "Ieškoti",
    "Send" : "Siųsti",
    "Refresh" : "Įkelti iš naujo",
    "Ok" : "Gerai",
    "Certificate updated" : "Liudijimas atnaujintas",
    "Could not update certificate" : "Nepavyko atnaujinti liudijimo",
    "{commonName} - Valid until {expiryDate}" : "{commonName} – Galioja iki {expiryDate}",
    "Encrypt with S/MIME and send later" : "Šifruoti naudojant S/MIME ir siųsti vėliau",
    "Encrypt with S/MIME and send" : "Šifruoti naudojant S/MIME ir siųsti",
    "Encrypt with Mailvelope and send later" : "Šifruoti naudojant Mailvelope ir siųsti vėliau",
    "Encrypt with Mailvelope and send" : "Šifruoti naudojant Mailvelope ir siųsti",
    "Send later" : "Siųsti vėliau",
    "Turn off formatting" : "Išjungti formatavimą",
    "Turn off and remove formatting" : "Išjungti ir šalinti formatavimą",
    "Keep formatting" : "Palikti formatavimą",
    "From" : "Nuo",
    "Select account" : "Pasirinkti paskyrą",
    "To" : "Kam",
    "Contact or email address …" : "Adresatas ar el. pašto adresas…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Tema",
    "Subject …" : "Tema…",
    "This message came from a noreply address so your reply will probably not be read." : "Šis laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Šie gavėjai neturi S/MIME liudijimo: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Šie gavėjai neturi PGP rakto: {recipients}.",
    "Write message …" : "Rašykite laišką…",
    "Saving draft …" : "Įrašomas juodraštis…",
    "Error saving draft" : "Klaida įrašant juodraštį",
    "Draft saved" : "Juodraštis įrašytas",
    "Save draft" : "Įrašyti juodraštį",
    "Discard & close draft" : "Atmesti ir užverti juodraštį",
    "Enable formatting" : "Įjungti formatavimą",
    "Disable formatting" : "Išjungti formatavimą",
    "Upload attachment" : "Įkelti priedą",
    "Add attachment from Files" : "Pridėti priedą iš Failų",
    "Sign message with S/MIME" : "Pasirašyti laišką naudojant S/MIME",
    "Encrypt message with S/MIME" : "Šifruoti laišką naudojant S/MIME",
    "Encrypt message with Mailvelope" : "Šifruoti laišką naudojant Mailvelope",
    "Send now" : "Siųsti dabar",
    "Custom date and time" : "Tinkinta data ir laikas",
    "Enter a date" : "Įveskite datą",
    "Choose" : "Pasirinkite",
    "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
    "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
    "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
    "Confirm" : "Patvirtinti",
    "Tag: {name} deleted" : "Žyma: {name} ištrinta",
    "An error occurred, unable to delete the tag." : "Įvyko klaida, nepavyko ištrinti žymos.",
    "Plain text" : "Grynasis tekstas",
    "Rich text" : "Raiškusis tekstas",
    "No messages in this folder" : "Šiame aplanke laiškų nėra",
    "No messages" : "Nėra laiškų",
    "No subject" : "Be temos",
    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
    "Set reminder for later today" : "Nustatyti priminimą šiandien vėliau",
    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
    "Set reminder for tomorrow" : "Nustatyti priminimą rytoj",
    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
    "Set reminder for this weekend" : "Nustatyti priminimą šį savaitgalį",
    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
    "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
    "Could not delete message" : "Nepavyko ištrinti laiško",
    "Could not archive message" : "Nepavyko archyvuoti laiško",
    "Encrypted message" : "Šifruotas laiškas",
    "This message is unread" : "Šis laiškas yra neskaitytas",
    "Unfavorite" : "Nebežymėti kaip mėgstamą",
    "Favorite" : "Mėgstamas",
    "Read" : "Skaityti",
    "Edit tags" : "Taisyti žymas",
    "Move thread" : "Perkelti giją",
    "Archive thread" : "Archyvuoti giją",
    "Delete thread" : "Ištrinti giją",
    "Delete message" : "Ištrinti laišką",
    "More actions" : "Daugiau veiksmų",
    "Back" : "Atgal",
    "Edit as new message" : "Taisyti kaip naują laišką",
    "Create task" : "Sukurti užduotį",
    "Download message" : "Atsisiųsti laišką",
    "Load more" : "Įkelti daugiau",
    "_Mark {number} read_::_Mark {number} read_" : ["Žymėti {number} kaip skaitytą","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytą"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Žymėti {number} kaip neskaitytą","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytą"],
    "Mark as unread" : "Žymėti kaip neskaitytą",
    "Mark as read" : "Žymėti kaip skaitytą",
    "Report this bug" : "Pranešti apie šią klaidą",
    "Event created" : "Įvykis sukurtas",
    "Could not create event" : "Nepavyko sukurti įvykio",
    "Create event" : "Sukurti įvykį",
    "All day" : "Visą dieną",
    "Attendees" : "Kviestiniai",
    "Description" : "Aprašas",
    "Create" : "Sukurti",
    "This event was updated" : "Šis įvykis buvo atnaujintas",
    "{attendeeName} accepted your invitation" : "{attendeeName} priėmė jūsų pakvietimą",
    "{attendeeName} declined your invitation" : "{attendeeName} atmetė jūsų pakvietimą",
    "You accepted this invitation" : "Jūs priėmėte šį pakvietimą",
    "You declined this invitation" : "Jūs atmetėte šį pakvietimą",
    "Save to" : "Įrašyti į",
    "Select" : "Pasirinkti",
    "Comment" : "Komentaras",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "More options" : "Daugiau parinkčių",
    "Could not remove internal address {sender}" : "Nepavyko pašalinti vidinio adreso {sender}",
    "Could not add internal address {address}" : "Nepavyko pridėti vidinį adresą {address}",
    "Remove" : "Šalinti",
    "email" : "elektroninis paštas",
    "Add internal address" : "Pridėti vidinį adresą",
    "Last hour" : "Paskutinė valanda",
    "Today" : "Šiandien",
    "Last week" : "Praeitą savaitę",
    "Last month" : "Praeitą mėnesį",
    "Loading messages …" : "Įkeliami laiškai…",
    "Choose target folder" : "Pasirinkite paskirties aplanką",
    "Important info" : "Svarbi informacija",
    "Other" : "Kita",
    "The sender of this message has asked to be notified when you read this message." : "Šio laiško siuntėjas paprašė, kad jam būtų pranešta, kai perskaitysite šį laišką.",
    "Notify the sender" : "Pranešti siuntėjui",
    "You sent a read confirmation to the sender of this message." : "Jūs išsiuntėte šio laiško siuntėjui patvirtinimą, kad perskaitėte jo laišką.",
    "Forward" : "Persiųsti",
    "Move message" : "Perkelti laišką",
    "Translate" : "Verskite",
    "Forward message as attachment" : "Persiųsti laišką kaip priedą",
    "Message body" : "Pagrindinė laiško dalis",
    "Unnamed" : "Be pavadinimo",
    "Embedded message" : "Įterptas laiškas",
    "Attachment could not be saved" : "Nepavyko įrašyti priedo",
    "calendar imported" : "kalendorius importuotas",
    "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
    "Import into calendar" : "Importuoti į kalendorių",
    "Download attachment" : "Atsisiųsti priedą",
    "Save to Files" : "Įrašyti į Failus",
    "Error while saving attachments" : "Klaida įrašant priedus",
    "View fewer attachments" : "Rodyti mažiau priedų",
    "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
    "Save all to Files" : "Įrašyti visus į Failus",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Rodyti dar {count} priedą","Rodyti dar {count} priedus","Rodyti dar {count} priedų","Rodyti dar {count} priedą"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Šis laiškas yra šifruotas naudojant PGP. Norėdami jį iššifruoti, įsidiekite Mailvelope.",
    "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
    "Show images" : "Rodyti paveikslus",
    "Show images temporarily" : "Laikinai rodyti paveikslus",
    "Always show images from {sender}" : "Visada rodyti paveikslus nuo {sender}",
    "Always show images from {domain}" : "Visada rodyti paveikslus iš {domain}",
    "Quoted text" : "Cituojamas tekstas",
    "Move" : "Perkelti",
    "Remove account" : "Šalinti paskyrą",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Paskyra {email} ir podėlyje esantys el. pašto duomenys bus pašalinti iš Nextcloud, tačiau nebus pašalinti iš jūsų el. pašto teikėjo puslapio.",
    "Remove {email}" : "Šalinti {email}",
    "Show only subscribed folders" : "Rodyti tik prenumeruotus aplankus",
    "Add folder" : "Pridėti aplanką",
    "Folder name" : "Aplanko pavadinimas",
    "Saving" : "Įrašoma",
    "Move up" : "Pakelti",
    "Move down" : "Nuleisti",
    "Show all subscribed folders" : "Rodyti visus prenumeruotus aplankus",
    "Show all folders" : "Rodyti visus aplankus",
    "Collapse folders" : "Suskleisti aplankus",
    "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
    "Loading …" : "Įkeliama…",
    "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
    "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
    "The folder and all messages in it will be deleted." : "Aplankas ir visi jame esantys laiškai bus ištrinti.",
    "Delete folder" : "Ištrinti aplanką",
    "Delete folder {name}" : "Ištrinti aplanką {name}",
    "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
    "Mark all as read" : "Žymėti visus kaip skaitytus",
    "Mark all messages of this folder as read" : "Žymėti visus laiškus šiame aplanke kaip skaitytus",
    "Add subfolder" : "Pridėti poaplankį",
    "Rename" : "Pervadinti",
    "Move folder" : "Perkelti aplanką",
    "Clear cache" : "Išvalyti podėlį",
    "Subscribed" : "Prenumeruotas",
    "Sync in background" : "Sinchronizuoti fone",
    "New message" : "Naujas laiškas",
    "Edit message" : "Taisyti laišką",
    "Draft" : "Juodraštis",
    "Reply" : "Atsakyti",
    "Message saved" : "Laiškas įrašytas",
    "Failed to save message" : "Nepavyko įrašyti laiško",
    "Failed to save draft" : "Nepavyko įrašyti juodraščio",
    "attachment" : "priedas",
    "Message discarded" : "Laiškas atmestas",
    "Could not discard message" : "Nepavyko atmesti laiško",
    "Error sending your message" : "Klaida siunčiant jūsų laišką",
    "Retry" : "Bandyti dar kartą",
    "Send anyway" : "Vis tiek siųsti",
    "Autoresponder off" : "Atsakiklis išjungtas",
    "Autoresponder on" : "Atsakiklis įjungtas",
    "Message" : "Žinutė",
    "Oh Snap!" : "O, ne!",
    "Pending or not sent messages will show up here" : "Čia bus rodomi laukiantys ar neišsiųsti laiškai",
    "Mail server error" : "Pašto serverio klaida",
    "Message could not be sent" : "Nepavyko išsiųsti laiško",
    "Message deleted" : "Laiškas ištrintas",
    "Hide suspicious links" : "Slėpti įtartinas nuorodas",
    "Show suspicious links" : "Rodyti įtartinas nuorodas",
    "Copied email address to clipboard" : "El. pašto adresas nukopijuotas į iškarpinę",
    "Could not copy email address to clipboard" : "Nepavyko nukopijuoti el. pašto adreso į iškarpinę",
    "Contacts with this address" : "Adresatai turintys šį adresą",
    "New Contact" : "Naujas adresatas",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Contact name …" : "Adresato vardas…",
    "Add" : "Pridėti",
    "Show less" : "Rodyti mažiau",
    "Show more" : "Rodyti daugiau",
    "Clear" : "Išvalyti",
    "Close" : "Užverti",
    "Date" : "Data",
    "Tags" : "Žymos",
    "Select tags" : "Pasirinkti žymas",
    "Last 7 days" : "Paskutinės 7 dienos",
    "Custom" : "Tinkinti",
    "Signature …" : "Parašas…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Jūsų parašas yra didesnis nei 2 MB. Tai gali paveikti redaktoriaus našumą.",
    "Save signature" : "Įrašyti parašą",
    "Message source" : "Pirminis laiško kodas",
    "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymos.",
    "Delete tag" : "Ištrinti žymą",
    "Tag name is a hidden system tag" : "Žymos pavadinimas yra paslėpta sistemos žyma",
    "Tag already exists" : "Žyma jau yra",
    "Tag name cannot be empty" : "Žymos pavadinimas negali būti tuščias",
    "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymos.",
    "Add default tags" : "Pridėti numatytąsias žymas",
    "Add tag" : "Pridėti žymą",
    "Saving tag …" : "Įrašoma žyma…",
    "Task created" : "Užduotis sukurta",
    "Could not create task" : "Nepavyko sukurti užduoties",
    "Not found" : "Nerasta",
    "This message was encrypted by the sender before it was sent." : "Siuntėjas, prieš išsiųsdamas šį laišką, jį užšifravo.",
    "Reply all" : "Atsakyti visiems",
    "Disable reminder" : "Išjungti priminimą",
    "Unsubscribe" : "Atsisakyti prenumeratos",
    "Reply to sender only" : "Atsakyti tik siuntėjui",
    "Unsubscribe via link" : "Atsisakyti prenumeratos per nuorodą",
    "Unsubscribe via email" : "Atsisakyti prenumeratos per el. paštą",
    "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
    "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
    "Untitled event" : "Įvykis be pavadinimo",
    "(organizer)" : "(organizatorius)",
    "Import into {calendar}" : "Importuoti į {calendar}",
    "Event imported into {calendar}" : "Įvykis importuotas į {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Skrydis {flightNr} iš {depAirport} į {arrAirport}",
    "Airplane" : "Lėktuvas",
    "Reservation {id}" : "Rezervacija {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
    "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
    "Train" : "Traukinys",
    "Delete action" : "Ištrinti veiksmą",
    "Recipient" : "Gavėjas",
    "Delete filter" : "Ištrinti filtrą",
    "Delete mail filter {filterName}?" : "Ištrinti pašto filtrą {filterName}?",
    "New filter" : "Naujas filtras",
    "Filter saved" : "Filtras įrašytas",
    "Could not save filter" : "Nepavyko įrašyti filtro",
    "Filter deleted" : "Filtras ištrintas",
    "Could not delete filter" : "Nepavyko ištrinti filtro",
    "matches" : "atitinka",
    "Priority" : "Pirmenybė",
    "Enable filter" : "Įjungti filtrą",
    "Save filter" : "Įrašyti filtrą",
    "Error saving config" : "Klaida įrašant konfigūraciją",
    "Mail app" : "Pašto programėlė",
    "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Čia galite rasti egzemplioriaus masto nustatymus. Specifinius naudotojo nustatymus galite rasti pačioje programėlėje (apatiniame kairiajame kampe).",
    "Add new config" : "Pridėti naują konfigūraciją",
    "Allow additional mail accounts" : "Leisti papildomas pašto paskyras",
    "Gmail integration" : "„Gmail“ integracija",
    "Microsoft integration" : "„Microsoft“ integracija",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Pradinis laiškas bus pridėtas kaip priedas „message/rfc822“.",
    "Reset" : "Atstatyti",
    "Google integration configured" : "„Google“ integracija sukonfigūruota",
    "Could not configure Google integration" : "Nepavyko sukonfigūruoti „Google“ integracijos",
    "Google integration unlinked" : "„Google“ integracija atsieta",
    "Could not unlink Google integration" : "Nepavyko atsieti „Google“ integracijos",
    "Client ID" : "Kliento ID",
    "Client secret" : "Kliento paslaptis",
    "Unlink" : "Atsieti",
    "Microsoft integration configured" : "„Microsoft“ integracija sukonfigūruota",
    "Could not configure Microsoft integration" : "Nepavyko sukonfigūruoti „Microsoft“ integracijos",
    "Microsoft integration unlinked" : "„Microsoft“ integracija atsieta",
    "Could not unlink Microsoft integration" : "Nepavyko atsieti „Microsoft“ integracijos",
    "Email: {email}" : "El. paštas: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
    "Email address template" : "El. pašto adreso šablonas",
    "IMAP" : "IMAP",
    "User" : "Naudotojas",
    "Host" : "Serveris",
    "Port" : "Prievadas",
    "SMTP" : "SMTP",
    "Save Config" : "Įrašyti konfigūraciją",
    "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
    "Certificate imported successfully" : "Liudijimas sėkmingai importuotas",
    "Failed to import the certificate" : "Nepavyko importuoti liudijimo",
    "S/MIME certificates" : "S/MIME liudijimai",
    "Certificate name" : "Liudijimo pavadinimas",
    "E-mail address" : "El. pašto adresas",
    "Valid until" : "Galioja iki",
    "Delete certificate" : "Ištrinti liudijimą",
    "Import certificate" : "Importuoti liudijimą",
    "Import S/MIME certificate" : "Importuoti S/MIME liudijimą",
    "PKCS #12 Certificate" : "PKCS #12 liudijimas",
    "PEM Certificate" : "PEM liudijimas",
    "Certificate" : "Liudijimas",
    "Submit" : "Pateikti",
    "Shared" : "Bendrinama",
    "Shares" : "Viešiniai",
    "Account connected" : "Paskyra prijungta",
    "You can close this window" : "Galite užverti šį langą",
    "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
    "To add a mail account, please contact your administrator." : "Norėdami pridėti pašto paskyrą, susisiekite su savo administratoriumi.",
    "All" : "Visos",
    "Drafts" : "Juodraščiai",
    "Favorites" : "Mėgstami",
    "All inboxes" : "Visos pašto dėžutės",
    "Inbox" : "Gauta",
    "Junk" : "Šlamštas",
    "Sent" : "Išsiųsta",
    "Trash" : "Šiukšlinė",
    "Error while sharing file" : "Klaida bendrinant failą",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n naujas laiškas \nnuo {from}","%n nauji laiškai \nnuo {from}","%n naujų laiškų \nnuo {from}","%n naujų laiškų \nnuo {from}"],
    "Nextcloud Mail" : "Nextcloud el. paštas",
    "Discard changes" : "Atmesti pakeitimus",
    "Discard unsaved changes" : "Atmesti neįrašytus pakeitimus",
    "Keep editing message" : "Toliau taisyti laišką",
    "Attachments were not copied. Please add them manually." : "Priedai nebuvo nukopijuoti. Pridėkite juos rankiniu būdu.",
    "Message sent" : "Laiškas išsiųstas",
    "Could not send message" : "Nepavyko išsiųsti laiško",
    "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Atsirado problemų įkeliant {tag}{name}{endtag}",
    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
    "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
    "Could not load the message" : "Nepavyko įkelti laiško",
    "Error loading message" : "Klaida įkeliant laišką",
    "Forwarding to %s" : "Persiunčiama į %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
    "Redirect" : "Peradresuoti",
    "The link leads to %s" : "Nuoroda veda į %s",
    "Continue to %s" : "Tęsti į %s",
    "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
